About
=====

Links
-----

:Website: https://pypeec.otvam.ch
:Repository: https://github.com/otvam/pypeec
:Releases: https://github.com/otvam/pypeec/releases
:Tags: https://github.com/otvam/pypeec/tags
:Issues: https://github.com/otvam/pypeec/issues
:PyPi: https://pypi.org/project/pypeec

Author
------

* **Thomas Guillod**, Dartmouth College, NH, USA
* Email: guillod@otvam.ch
* Website: https://otvam.ch

Credits
-------

PyPEEC was created at **Dartmouth College** by the research group of **Prof. Sullivan**:

* Dartmouth College, NH, USA: https://dartmouth.edu
* Dartmouth Engineering: https://engineering.dartmouth.edu
* PMIC: https://pmic.engineering.dartmouth.edu

Special thanks to Yue (Will) Wu for discovering and reporting several bugs.

The FFT-accelerated PEEC method with voxels has been first described and implemented in:

* Torchio, R., IEEE TPEL, 10.1109/TPEL.2021.3092431, 2022
* Torchio, R., https://github.com/UniPD-DII-ETCOMP/FFT-PEEC

Other interesting papers and codes about similar methods:

* Yucel, A., IEEE TMTT, 10.1109/TMTT.2017.2785842, 2018
* Bettini, P., IOP, 10.1088/1361-6587/abce8f, 2020
* Marconato, N., ICECCME, 10.1109/ICECCME52200.2021.9590864, 2021
* Yucel, A., https://github.com/acyucel/VoxHenry

Copyright
---------

.. Important::
    \(c\) 2023-2024 / Thomas Guillod / Dartmouth College

.. Important::
    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/.
